
.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. mdinclude:: ../../README.md

Geometric Algebra Primitives
============================

.. py:currentmodule:: flowws_keras_geometry.algebra

.. autofunction:: vecvec

.. autofunction:: vecvec_invariants

.. autofunction:: vecvec_covariants

.. autofunction:: bivecvec

.. autofunction:: bivecvec_invariants

.. autofunction:: bivecvec_covariants

.. autofunction:: trivecvec

.. autofunction:: trivecvec_invariants

.. autofunction:: trivecvec_covariants

Geometric Algebra Layers
========================

.. py:currentmodule:: flowws_keras_geometry.layers

.. autoclass:: GradientLayer

.. autoclass:: NeighborhoodReduction

.. autoclass:: PairwiseVectorDifference

.. autoclass:: PairwiseVectorDifferenceSum

.. autoclass:: VectorAttention

.. autoclass:: Vector2VectorAttention

Data sources
============

.. py:currentmodule:: flowws_keras_geometry.data

.. autoclass:: MD17

.. autoclass:: PDBCache

.. autoclass:: PDBCoarseGrained

.. autoclass:: PyriodicDataset

.. autoclass:: RMD17

Model Architectures
===================

.. py:currentmodule:: flowws_keras_geometry.models

.. autoclass:: CrystalStructureClassification

.. autoclass:: MoleculeForceRegression

.. autoclass:: PDBInverseCoarseGrain

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
